@@ -3,6 +3,8 @@ from skimage.metrics import structural_similarity as ssim
 from skimage.metrics import mean_squared_error
 
 import imutils
+import imagehash
+from PIL import Image
 
 class ComputerVision:
 
@@ -47,3 +49,8 @@ class ComputerVision:
             return False
         else:
             return True
+
+    def diff_with_phash_image_hash(self, filenameA, filenameB):
+        base_line_hash = imagehash.phash(Image.open(filenameA))
+        compare_base_line_hash = imagehash.phash(Image.open(filenameB))
+        return (base_line_hash == compare_base_line_hash)
\ No newline at end of file
