@@ -1,8 +1,6 @@
 # Created by Jan Rummens at 8/01/2021
 from nemonet.runner.vision_runner import Runner
-from nemonet.engines.reporter import Reporter
 import typer
-import sys
 import traceback
 
 app = typer.Typer()
@@ -22,8 +20,4 @@ def scenario(name: str, useconfig: bool = False):
     except Exception as err:
         traceback.print_tb(err.__traceback__)
     finally:
-        reporter = Reporter()
-        if runner.scenario_passed():
-            reporter.publish(name, Reporter.status_passed)
-        else:
-            reporter.publish(name, Reporter.status_failed)
+        pass
